@@ -53,13 +53,7 @@ class Query
     var $dateFrom;          // 01.01.1970
     var $dateTo;            // 31.12.2011
     var $type;              // Type of this query: Simple, Ext, Konv
-
-    /**
-     * array with sort conditions
-     *
-     *   array('field' => 'Date', 'ascending' => 'false')
-     */
-    var $sort;
+    var $sort;              // DateAsc, SubjecDesc
 
 
     /**
@@ -81,7 +75,7 @@ class Query
         $this->headerValue = $headerValue;
         $this->isAttachment = $isAttachment;
         $this->isSpam = $isSpam;
-        $this->sort  = array('field' => 'Date', 'ascending' => 'false');
+        $this->sort  = 'DateAsc';
         $this->type = $type;
 
         $this->spamQuery = $App->getConfig('SPAM_QUERY','NOT HEADER-X-SPAM-FLAG:YES');
@@ -178,6 +172,7 @@ class Query
      */
     function getSortField()
     {
+
         if ($this->sort) {
             $sortField = preg_replace('/(.+)(Asc|Desc)$/','$1',$this->sort);
         }
